# Heritage Observatory Core Python Library

Heritage Observatory Core Python Library is a repository of reusable Python components to be shared by some Python projects using the Heritage Observatory RESTful API.

These components have minimal dependencies on other libraries, so that they can be deployed easily.  In addition, these components will keep their interfaces as stable as possible, so that other Python projects can integrate these components without having to worry about changes in the future.
